# acorn-babel

**acorn-babel** is not supported outside of babel usage. Do not expect support if
you use this in your own applications.

Deviates from [acorn](https://github.com/marijnh/acorn) in the following ways:

 * JSX support via [acorn-jsx](https://github.com/RReverser/acorn-jsx)
 * [ES7 Abstract references](https://github.com/zenparsing/es-abstract-refs)
 * [ES7 Async/await](https://github.com/lukehoban/ecmascript-asyncawait)
 * [ES7 Exponentiation operator](https://github.com/rwaldron/exponentiation-operator)
 * [ES7 Object rest/spread](https://github.com/sebmarkbage/ecmascript-rest-spread)
 * [Babel Playground features](https://babeljs.io/docs/usage/playground)
